"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tester = void 0;
var code_128_reader_1 = require("../../readers/code-128.reader");
var Tester = /** @class */ (function (_super) {
    __extends(Tester, _super);
    function Tester() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Tester.prototype.testParseValues = function (v) {
        return this.parseValues(v);
    };
    Tester.prototype.testGetAi = function (c) {
        return this.findAi(c);
    };
    Tester.prototype.testValidate = function (v) {
        return this.validate(v);
    };
    Tester.prototype.removeControlCharacters = function (value) {
        return _super.prototype.removeControlCharacters.call(this, value);
    };
    return Tester;
}(code_128_reader_1.Code128Reader));
exports.Tester = Tester;
describe('Code128Reader', function () {
    var config;
    var classUnderTest;
    beforeEach(function () {
        config = {
            delimiter: ' ',
            identifier: '[C0',
        };
        classUnderTest = new Tester(config);
    });
    describe('validate', function () {
        test('should validate identifier is prefixed', function () {
            /* tslint:disable */
            expect(classUnderTest.validate('ABCDEFG')).toBe(false);
            expect(classUnderTest.validate('C1')).toBe(false);
            expect(classUnderTest.validate(']]C0')).toBe(false);
            expect(classUnderTest.validate(']C0A')).toBe(true);
            expect(classUnderTest.validate(']C0111111111111111111111111')).toBe(true);
            /* tslint:enable */
        });
        test('should validate value is at least 1 character', function () {
            /* tslint:disable */
            expect(classUnderTest['validate'](']C0')).toBe(false);
            expect(classUnderTest['validate'](']C0A')).toBe(true);
            /* tslint:enable */
        });
    });
    describe('parseValues', function () {
        test('should parse single fixed width AI', function () {
            var actual = classUnderTest.testParseValues('0196283290839476');
            expect(actual).toContainEqual({
                code: '01',
                value: '96283290839476',
            });
            var actual1 = classUnderTest.testParseValues('11150523');
            expect(actual1).toContainEqual({ code: '11', value: '150523' });
        });
        test('should parse multiple fixed width AI', function () {
            var actual = classUnderTest.testParseValues('019628329083947611150523');
            expect(actual).toContainEqual({
                code: '01',
                value: '96283290839476',
            });
            expect(actual).toContainEqual({ code: '11', value: '150523' });
            var actual1 = classUnderTest.testParseValues('01962832908394761115052312999999');
            expect(actual1).toContainEqual({
                code: '01',
                value: '96283290839476',
            });
            expect(actual1).toContainEqual({ code: '11', value: '150523' });
            expect(actual1).toContainEqual({ code: '12', value: '999999' });
        });
        test('should parse variable length value less than max length', function () {
            var actual2 = classUnderTest.testParseValues('10ES005867003');
            expect(actual2).toContainEqual({
                code: '10',
                value: 'ES005867003',
            });
        });
        test('should parse fractional values', function () {
            // scale 0
            var actual0 = classUnderTest.testParseValues('3300010000');
            expect(actual0).toContainEqual({ code: '330', value: 10000 });
            // scale 2
            var actual = classUnderTest.testParseValues('3302010000');
            expect(actual).toContainEqual({ code: '330', value: 100.0 });
            // scale 4
            var actual1 = classUnderTest.testParseValues('3224999999');
            expect(actual1).toContainEqual({ code: '322', value: 99.9999 });
            // scale 6
            var actual2 = classUnderTest.testParseValues('3616123456');
            expect(actual2).toContainEqual({ code: '361', value: 0.123456 });
        });
        test('should handle fractional after non-fractional', function () {
            var actual = classUnderTest.testParseValues('36161234560196283290839476');
            expect(actual).toContainEqual({ code: '361', value: 0.123456 });
            expect(actual).toContainEqual({
                code: '01',
                value: '96283290839476',
            });
        });
        test('should handle non-fractional after fractional ', function () {
            var actual = classUnderTest.testParseValues('01962832908394763916123456');
            expect(actual).toContainEqual({ code: '391', value: 0.123456 });
            expect(actual).toContainEqual({
                code: '01',
                value: '96283290839476',
            });
        });
    });
    describe('findAi', function () {
        test('should get 2 character Ai', function () {
            var testVals = ['01', '0199999', '01ABCDEFG'];
            testVals.forEach(function (val) {
                var actual = classUnderTest.testGetAi(val);
                expect(actual.code).toBe('01');
                expect(actual.description).toBe('Global Trade Item Number');
                expect(actual.length).toBe(14);
                /* tslint:disable */
                expect(actual.variableLength).toBe(false);
                /* tslint:enable */
            });
        });
        test('should get 3 character Ai', function () {
            var testVals = ['241', '241ABCDEFG', '2419999999'];
            testVals.forEach(function (val) {
                var actual = classUnderTest.testGetAi(val);
                expect(actual.code).toBe('241');
                expect(actual.description).toBe('Customer Part Number');
                expect(actual.length).toBe(30);
                /* tslint:disable */
                expect(actual.variableLength).toBe(true);
                /* tslint:enable */
            });
        });
        test('should get 4 character Ai', function () {
            var testVals = ['8020', '8020ABCDEFGHIJ', '8020999999999'];
            testVals.forEach(function (val) {
                var actual = classUnderTest.testGetAi(val);
                expect(actual.code).toBe('8020');
                expect(actual.description).toBe('Payment slip preference number');
                expect(actual.length).toBe(25);
                /* tslint:disable */
                expect(actual.variableLength).toBe(true);
                /* tslint:enable */
            });
        });
    });
    describe('decode', function () {
        test('should split on default delimiter', function () {
            var actual = classUnderTest.decode(']C012999999101 1001 2101');
            expect(actual.values).toContainEqual({
                code: '12',
                value: '999999',
            });
            expect(actual.values).toContainEqual({ code: '10', value: '1' });
            expect(actual.values).toContainEqual({ code: '10', value: '01' });
            expect(actual.values).toContainEqual({ code: '21', value: '01' });
        });
        test('should split on space if no specified delimiter', function () {
            config = {
                delimiter: '',
                identifier: ']C0',
            };
            classUnderTest = new Tester(config);
            var actual = classUnderTest.decode(']C00196283290839476101 1001 2101');
            expect(actual.values).toContainEqual({
                code: '01',
                value: '96283290839476',
            });
            expect(actual.values).toContainEqual({ code: '10', value: '1' });
            expect(actual.values).toContainEqual({ code: '10', value: '01' });
            expect(actual.values).toContainEqual({ code: '21', value: '01' });
        });
    });
    describe('removeControlCharacters', function () {
        test('should replace control characters with delimiter', function () {
            var expected = ']C002084135560009503703 10ES003472002';
            var input = expected.replace(' ', String.fromCharCode(29));
            expect(classUnderTest.removeControlCharacters(input)).toBe(expected);
        });
    });
    test('should parse known Code128s', function () {
        var actual = classUnderTest.decode(']C0019628329083134011150523310200059421145143242042');
        var actual1 = classUnderTest.decode(']C0019628329083947611150529310200178721145149307335');
        var actual2 = classUnderTest.decode(']C002084135560009503703 10ES003472002');
        var actual3 = classUnderTest.decode(']C002084135560009503703 10ES003472002'.replace(' ', String.fromCharCode(29)));
        var actual4 = classUnderTest.decode(']C00110606322100502 10CHPA2777001');
        expect(actual.values).toContainEqual({
            code: '21',
            value: '145143242042',
        });
        expect(actual.values).toContainEqual({ code: '310', value: 5.94 });
        expect(actual.values).toContainEqual({ code: '11', value: '150523' });
        expect(actual.values).toContainEqual({
            code: '01',
            value: '96283290831340',
        });
        expect(actual1.values).toContainEqual({
            code: '21',
            value: '145149307335',
        });
        expect(actual1.values).toContainEqual({ code: '310', value: 17.87 });
        expect(actual1.values).toContainEqual({ code: '11', value: '150529' });
        expect(actual1.values).toContainEqual({
            code: '01',
            value: '96283290839476',
        });
        expect(actual2.values).toContainEqual({
            code: '02',
            value: '08413556000950',
        });
        expect(actual2.values).toContainEqual({ code: '37', value: '03' });
        expect(actual2.values).toContainEqual({
            code: '10',
            value: 'ES003472002',
        });
        expect(actual3.values).toContainEqual({
            code: '02',
            value: '08413556000950',
        });
        expect(actual3.values).toContainEqual({ code: '37', value: '03' });
        expect(actual3.values).toContainEqual({
            code: '10',
            value: 'ES003472002',
        });
        expect(actual4.values).toContainEqual({
            code: '01',
            value: '10606322100502',
        });
        expect(actual4.values).toContainEqual({
            code: '10',
            value: 'CHPA2777001',
        });
    });
});
//# sourceMappingURL=code-128.reader.spec.js.map