"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestClass = void 0;
var code_39_reader_1 = require("../../readers/code-39.reader");
var enums_1 = require("../../enums");
var TestClass = /** @class */ (function (_super) {
    __extends(TestClass, _super);
    function TestClass() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TestClass.prototype.decode = function (val) {
        return this.decode(val);
    };
    TestClass.prototype.validate = function (val) {
        return this.validate(val);
    };
    return TestClass;
}(code_39_reader_1.Code39Reader));
exports.TestClass = TestClass;
describe('code39Reader', function () {
    var config = {};
    var classUnderTest;
    var decodeValues = [
        enums_1.AimCodes.CODE39 + 'P0010065330101',
        enums_1.AimCodes.CODE39 + 'I0010065330101',
        enums_1.AimCodes.CODE39 + 'M0010065330101',
        enums_1.AimCodes.CODE39 + 'ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890-$%.+/',
        enums_1.AimCodes.CODE39 + 'A',
        enums_1.AimCodes.CODE39 + '1234567777777',
    ];
    var invalidValues = [
        ']B011111111111111111111111111111111111111111111',
        ']A011111111111111111111111111111111111111111111',
        'ABCDEFGhIJKLMNOPQRSTUVWXYZ1234567890-$%.+/',
        '',
        '~11223344',
        '1122#3344',
    ];
    beforeEach(function () {
        classUnderTest = new code_39_reader_1.Code39Reader(config);
    });
    describe('decode', function () {
        test('should include symbology in result', function () {
            var result = classUnderTest.decode(decodeValues[0]);
            expect(result.symbology).toBe('code_39');
        });
        test('should include rawValue in result', function () {
            var result = classUnderTest.decode(decodeValues[1]);
            expect(result.rawValue).toBe(decodeValues[1]);
        });
        it('should return entire value if no embedded data', function () {
            var configWithNoValues = {
                symbology: enums_1.Symbologies.Code39,
                values: [],
            };
            classUnderTest = new code_39_reader_1.Code39Reader(configWithNoValues);
            var result = classUnderTest.decode(decodeValues[5]);
            expect(result.values).toEqual('1234567777777');
        });
        it('should return entire value if no config', function () {
            classUnderTest = new code_39_reader_1.Code39Reader();
            var result = classUnderTest.decode(decodeValues[5]);
            expect(result.values).toEqual('1234567777777');
        });
        it('should parse embedded data indexes from config', function () {
            var configWithEmbeddedData = {
                symbology: enums_1.Symbologies.Code39,
                values: [
                    {
                        length: 2,
                        start: 0,
                        valueType: 'foo',
                    },
                    {
                        length: 3,
                        start: 2,
                        valueType: 'bar',
                    },
                ],
            };
            classUnderTest = new code_39_reader_1.Code39Reader(configWithEmbeddedData);
            var result = classUnderTest.decode(decodeValues[5]);
            expect(result.values).toEqual(expect.arrayContaining([
                { code: 'foo', value: '12' },
                { code: 'bar', value: '345' },
            ]));
        });
    });
    describe('validate', function () {
        decodeValues.forEach(function (value) {
            test('should return true for valid value: ' + value, function () {
                /* tslint:disable */
                expect(classUnderTest.validate(value)).toBe(true);
                /* tslint:enable */
            });
        });
        invalidValues.forEach(function (value) {
            test('should return false for invalid value: ' + value, function () {
                /* tslint:disable */
                expect(classUnderTest.validate(value)).toBe(false);
                /* tslint:enable */
            });
        });
    });
});
//# sourceMappingURL=code-39.reader.spec.js.map