"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GS1Reader = void 0;
var base_reader_1 = require("./base.reader");
var config_1 = require("../config");
var enums_1 = require("../enums");
var models_1 = require("../models");
var utils_1 = require("../utils");
var DELIMITER = ' ';
var GS1Reader = /** @class */ (function (_super) {
    __extends(GS1Reader, _super);
    function GS1Reader(readerConfig) {
        return _super.call(this, enums_1.Symbologies.GS1128, null, readerConfig) || this;
    }
    GS1Reader.prototype.validate = function (value) {
        var idPrefix = value.indexOf(enums_1.AimCodes.GS1);
        var valueLength = utils_1.AimParser.parseAimCode(this.symbology, value)
            .length;
        return idPrefix === 0 && valueLength > 0;
    };
    GS1Reader.prototype.decode = function (value) {
        var _this = this;
        var sterilizedValue = this.removeControlCharacters(value);
        var result = new models_1.BarcodeValue(this.symbology, value);
        try {
            this.tryValidate(value);
            var valWithoutId = utils_1.AimParser.parseAimCode(this.symbology, sterilizedValue);
            result.values = [].concat.apply([], valWithoutId.split(DELIMITER).map(function (val) { return _this.parseValues(val); }));
        }
        catch (ex) {
            result.success = false;
            result.errorMessage = ex;
        }
        return result;
    };
    GS1Reader.prototype.removeControlCharacters = function (value) {
        var result = value;
        config_1.CONTROLCHARS.forEach(function (charCode) {
            result = result.replace(String.fromCharCode(charCode), DELIMITER);
        });
        return result;
    };
    GS1Reader.prototype.findAi = function (value) {
        var ai = null;
        var codeLength = 2;
        var _loop_1 = function () {
            var code = value.substr(0, codeLength);
            var ais = this_1.aiList.filter(function (x) { return x.code === code; });
            if (ais.length > 0) {
                ai = ais[0];
            }
            else {
                codeLength++;
            }
        };
        var this_1 = this;
        while (ai === null && codeLength < 5) {
            _loop_1();
        }
        return ai;
    };
    GS1Reader.prototype.parseValue = function (ai, input) {
        var val = null;
        if (ai.fractional !== true) {
            val = input.substr(ai.code.length, ai.length);
        }
        else {
            var scale = Number(input.charAt(ai.code.length));
            var num = input.substr(ai.code.length + 1, ai.length);
            val = Number(num) / Math.pow(10, scale);
        }
        return {
            code: ai.code,
            value: val,
        };
    };
    GS1Reader.prototype.parseValues = function (input) {
        var vals = Array();
        var ai = this.findAi(input);
        if (input.length > ai.totalLength) {
            vals = vals.concat(this.parseValues(input.substr(ai.totalLength)));
        }
        vals.push(this.parseValue(ai, input));
        return vals;
    };
    Object.defineProperty(GS1Reader.prototype, "aiList", {
        get: function () {
            var _a, _b;
            return (((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.ai) != null)
                ? __spreadArrays(models_1.APPLICATION_IDENTIFIERS, [(_b = this.configuration) === null || _b === void 0 ? void 0 : _b.ai]) : models_1.APPLICATION_IDENTIFIERS;
        },
        enumerable: false,
        configurable: true
    });
    return GS1Reader;
}(base_reader_1.BaseReader));
exports.GS1Reader = GS1Reader;
//# sourceMappingURL=gs-1.reader.js.map